aboutsummaryrefslogtreecommitdiff
path: root/slirp/ip_icmp.c
diff options
context:
space:
mode:
authorblueswir1 <blueswir1@c046a42c-6fe2-441c-8c8c-71466251a162>2007-10-26 19:34:46 +0000
committerblueswir1 <blueswir1@c046a42c-6fe2-441c-8c8c-71466251a162>2007-10-26 19:34:46 +0000
commit7878ff6bc7c9bc4091d19a51a1dc4bac2df23560 (patch)
tree530fe0abc37ba5b90cdac67d9698b1bc27ce228a /slirp/ip_icmp.c
parent9634d9031c140b24c7ca0d8872632207f6ce7275 (diff)
Add const etc. to places forgotten from the previous commit
git-svn-id: svn://svn.savannah.nongnu.org/qemu/trunk@3453 c046a42c-6fe2-441c-8c8c-71466251a162
Diffstat (limited to 'slirp/ip_icmp.c')
-rw-r--r--slirp/ip_icmp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/slirp/ip_icmp.c b/slirp/ip_icmp.c
index b589651cad..d1da0a2fcd 100644
--- a/slirp/ip_icmp.c
+++ b/slirp/ip_icmp.c
@@ -42,8 +42,8 @@ struct icmpstat icmpstat;
#endif
/* The message sent when emulating PING */
-/* Be nice and tell them it's just a psuedo-ping packet */
-char icmp_ping_msg[] = "This is a psuedo-PING packet used by Slirp to emulate ICMP ECHO-REQUEST packets.\n";
+/* Be nice and tell them it's just a pseudo-ping packet */
+const char icmp_ping_msg[] = "This is a pseudo-PING packet used by Slirp to emulate ICMP ECHO-REQUEST packets.\n";
/* list of actions for icmp_error() on RX of an icmp message */
static const int icmp_flush[19] = {